=========================
Tempest plugin for Ironic
=========================

.. image:: https://governance.openstack.org/tc/badges/ironic-tempest-plugin.svg

This repository contains a Tempest_ plugin for OpenStack `Bare Metal`_
project.

* Free software: Apache license
* Documentation: https://docs.openstack.org/ironic-tempest-plugin
* Source: https://opendev.org/openstack/ironic-tempest-plugin
* Bugs: https://bugs.launchpad.net/ironic/+bugs

.. _Tempest: https://docs.openstack.org/tempest/latest/
.. _Bare Metal: https://docs.openstack.org/ironic/latest/
